@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: VariableProvider.java,v 1.13 2001/02/20 16:01:42 metlov Exp $
+ * $Id: VariableProvider.java,v 1.16 2001/06/08 15:48:59 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -15,6 +15,8 @@
 
 
 public class VariableProvider implements gnu.jel.DVResolver {
+  public Object anObject=new Object();
+
   public double xvar;
   
   public double x() {return xvar;};
@@ -163,7 +165,31 @@ public class VariableProvider implements gnu.jel.DVResolver {
   public gnu.jel.reflect.Long valLongJELObj=new LongObject(1);
   public gnu.jel.reflect.Float valFloatJELObj=new FloatObject((float)1.0);
   public gnu.jel.reflect.Double valDoubleJELObj=new DoubleObject(1.0);
+
+  public static boolean isNullDouble(java.lang.Double d) {
+    return d==null;
+  };
+
+  public static java.lang.Double getDoubleNull() {
+    return null;
+  };
+
   
+  public static int convertNumberToInt(Number n) {
+    return n.intValue();
+  };
+
+  public static int addNumbersInt(Number n1,Number n2) {
+    return n1.intValue()+n2.intValue();
+  };
+
+  public static double convertNumberToDouble(Number n) {
+    return n.doubleValue();
+  };
+
+  public static double addNumbersDbl(Number n1,Number n2) {
+    return n1.doubleValue()+n2.doubleValue();
+  };
   
   public static gnu.jel.reflect.Boolean makeJELBooleanObject(boolean b) {
     return new BooleanObject(b);
