@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: Library.java,v 1.11 2001/02/20 16:01:41 metlov Exp $
+ * $Id: Library.java,v 1.12 2001/03/07 20:19:23 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -61,7 +61,7 @@ public class Library {
 
   public DVResolver resolver;   // directly accessed from EC.jj
 
-  private Class provider=null;
+  public Hashtable cnmap;
 
   /**
    * Creates a library for JEL.
@@ -79,6 +79,12 @@ public class Library {
     this(staticLib,dynamicLib,dotClasses,null);
   };
 
+  public Library(Class[] staticLib,Class[] dynamicLib,Class[] dotClasses,
+                 DVResolver resolver) {
+    this(staticLib,dynamicLib,dotClasses,resolver,null);
+  };
+
+
   /**
    * Creates a library for JEL.
    * <P> The following should be kept in mind when constructing a library:
@@ -127,10 +133,9 @@ public class Library {
    * @param resolver is the object used to resolve the names.
    */
   public Library(Class[] staticLib,Class[] dynamicLib,Class[] dotClasses,
-                 DVResolver resolver) {
+                 DVResolver resolver,Hashtable cnmap) {
+    this.cnmap=cnmap;
     this.resolver=resolver;
-    if (resolver!=null)
-      this.provider=dynamicLib[dynamicLib.length-1];
     if (dotClasses==null) {
       this.dotClasses=null;
     } else {
@@ -248,15 +253,18 @@ public class Library {
     return stateless.containsKey(o);
   };
 
-//  gives nothing the direct acces to resolver is not able to give
-//  plus reduces flexibility (to change resilver at run-time)
-//  also the direct acces allows more optimizations
-//  and also removing this method saves space.
-//
-//    public String getDVTypeName(String name) {
-//      if (resolver==null) return null;
-//      return resolver.getTypeName(name);
-//    };
+  public Class getClassByName(String name) {
+    if (cnmap==null) return null;
+
+    if (Debug.enabled) {
+      // Just to print a meaningful diagnostics in the case user puts
+      // non-class object into the cnmap
+      Debug.assert(cnmap.get(name) instanceof Class,"All elements of cnmap "+
+                   "must be classes and \""+name+"\" is not.");
+    };
+
+    return (Class)cnmap.get(name);
+  };
   
   /**
    * Used to search library for method or field.
