@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPbinary.java,v 1.6 2001/02/13 21:45:22 metlov Exp $
+ * $Id: OPbinary.java,v 1.8 2001/02/28 23:30:13 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -112,8 +112,9 @@ public class OPbinary extends OPfunction {
       resID=0;
     case 1: // binary promotion
       op1cvtID=op2cvtID=opsIDX=
-        promotions[TypesStack.baseType[TypesStack.unwrapType[op1ID]]]
-        [TypesStack.baseType[TypesStack.unwrapType[op2ID]]];
+        promotions[TypesStack.unwrapType[op1ID]][TypesStack.unwrapType[op2ID]];
+      if (op1ID==10) op1cvtID=11; // remove TSB
+      if (op2ID==10) op2cvtID=11; // remove TSB
       if (resID<0) resID=opsIDX;
 
       if (opsIDX==-1) { // types are incompatible (can't promote)
@@ -168,13 +169,13 @@ public class OPbinary extends OPfunction {
     };
     
     // insert type conversion opcode
-    if (op1ID!=op1cvtID) {
+    if ((op1ID!=op1cvtID) && (op1cvtID!=8)) {
       typesStk.pushID(op1ID);
       list.addAfter(p1CvtPlaceholder,
                     new OPunary(typesStk,op1cvtID,null,false));
       typesStk.pop();
     };
-    if (op2ID!=op2cvtID) {
+    if ((op2ID!=op2cvtID) && (op2cvtID!=8)) {
       typesStk.pushID(op2ID);
       list.addAfter(p2CvtPlaceholder,
                     new OPunary(typesStk,op2cvtID,null,second_narrowing));
@@ -226,6 +227,27 @@ public class OPbinary extends OPfunction {
       OPload c1=(OPload) this.prev.prev;
       if (code==20) {
         ((StringBuffer)c1.what).append(String.valueOf(c2.what));
+      } else if ((TypesStack.baseType[c1.resID]==8) || 
+                 (TypesStack.baseType[c2.resID]==8)) {
+        // the only way the objects appear in this context
+        // are the comparisons
+        if (Debug.enabled) {
+          Debug.assert((code>=8)||(code<=13),
+                       "only comparisons and concatenation binops can "+
+                       "operate on objects.");
+          Debug.assert(c1.resID!=10, "No TSB in this context 1");
+          Debug.assert(c1.resID!=10, "No TSB in this context 2");
+        };
+
+        // only string literal comparisons are interpreted
+        if ((c1.resID!=11) || (c2.resID!=11)) return;
+
+        // compare the strings
+        int res=CompiledExpression.compare((String)c1.what,(String)c2.what);
+        c1.what=((0x3172A>>>(3*(code-8)))&((res>0)?1:((res<0)?4:2)))>0
+          ?Boolean.TRUE:Boolean.FALSE;
+        c1.resType=Boolean.TYPE;
+        c1.resID=0;
       } else {  // binary on primitive types
         // Widen
         Number n1=TypesStack.widen(c1.what,c1.resID);
