@@ -41,7 +41,7 @@ public final class Debug {
   /**
    * Determines if debugging is enabled in current compilation.
    */
-  public final static boolean enabled= true;   // <-- to be replaced
+  public final static boolean enabled= false;   // <-- to be replaced
 
   /**
    * Prints a line of the debug output.
