@@ -1,5 +1,5 @@
-/*
- * $Id: Tester.java,v 1.2 1999/12/19 17:43:31 metlov Exp $
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
+ * $Id: Tester.java,v 1.3 2000/02/11 22:08:18 metlov Exp $
  *
  * Galaxy PBW server 2.0 abstract core package.
  *
@@ -30,6 +30,8 @@ public class Tester {
   private long initTestTime;
   private OutputStream log_stream;
   private PrintWriter log;
+  private boolean printed;
+  private boolean printedNL;
   
   public Tester(OutputStream stream) {
     log_stream=stream;
@@ -41,10 +43,13 @@ public class Tester {
     if (Debug.enabled) {
       Debug.assert(doing==null,"Concurrent testing is not supported.");
       StringBuffer stb=new StringBuffer(descr);
-      stb.append(" ______________________________________________________________________");
+      stb.append(" ____________________________________________________"+
+                 "__________________");
       stb.setLength(60);
       doing=stb.toString();
       log.print(doing); log.flush();
+      printed=false;
+      printedNL=true;
       initTestTime=System.currentTimeMillis();
     };
   };
@@ -54,6 +59,10 @@ public class Tester {
       long elapsed=System.currentTimeMillis()-initTestTime;
       Debug.assert(doing!=null,"No test to succeed.");
       succ_tst++;
+      if (!printedNL) log.println();
+      if (printed)
+        log.print("^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"+
+                  "^^^^^^^");
       log.print(": OK   (in ");
       log.print(elapsed); totalTestTime+=elapsed;
       log.println(" ms)");
@@ -66,6 +75,10 @@ public class Tester {
       long elapsed=System.currentTimeMillis()-initTestTime;
       Debug.assert(doing!=null,"No test to fail.");
       fail_tst++;
+      if (!printedNL) log.println("   \\/ below \\/");
+      if (printed)
+        log.print("^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"+
+                  "^^^^^^^");
       log.print(": FAIL (in ");
       log.print(elapsed); totalTestTime+=elapsed;
       log.println(" ms)");
@@ -73,6 +86,23 @@ public class Tester {
     };
   };
 
+  public void print(Object obj) {
+    if (Debug.enabled) {
+      if (!printed) log.println("   \\/ below \\/");
+      printedNL=false;
+      printed=true;
+      log.print(obj);
+    };
+  };
+
+  public void println(Object obj) {
+    if (Debug.enabled) {
+      print(obj);
+      printedNL=true;
+      log.println();
+    };
+  };
+
   public void testFailProgressing() {
     if (Debug.enabled && (doing!=null)) testFail();
   };
@@ -191,7 +221,7 @@ GOT: XXXXXXXX DDDDDDDD DDDDDDDD DDDDDDDD DDDDDDDD  |AAAAAAAAAAAAAAAA |
     return "";
   };
 
-  public boolean compare(String got,String exp) {
+  public boolean compare(Object got,Object exp) {
     if (exp.equals(got)) {
       testOK();
       return true;
@@ -203,6 +233,11 @@ GOT: XXXXXXXX DDDDDDDD DDDDDDDD DDDDDDDD DDDDDDDD  |AAAAAAAAAAAAAAAA |
     return false;
   };
 
+  public boolean compare(boolean b) {
+    if (b) testOK(); else testFail();
+    return b;  
+  };
+
   public boolean compare(int got,int exp) {
     if (exp==got) {
       testOK();
