@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.28 2001/02/20 16:01:42 metlov Exp $
+ * $Id: TestSuite.java,v 1.32 2001/06/08 15:48:59 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -426,6 +426,92 @@ public class TestSuite {
     testExpression("\"\"+\"\"+aarr[1][0]","3.0", null, rtp, lib,o);
     testExpression("\"a\"+\"b\"+aarr[1][0]+\"c\"","ab3.0c", null, rtp, lib,o);
 
+    testExpression("\"a\"==\"b\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\"==\"a\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\"!=\"b\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\"!=\"a\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("!(\"a\"!=\"b\")",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("!(\"a\"==\"a\")",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\"+\"b\"==\"ab\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\"+\"b\"!=\"ab\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\"+\"b\"==\"a\"+\"b\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("!(\"a\"+\"b\"!=\"a\"+\"b\")",Boolean.TRUE,
+                   null, rtp, lib,o);
+
+    testExpression("\"a\"<\"b\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\"<=\"b\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\">=\"b\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\">\"b\"",Boolean.FALSE, null, rtp, lib,o);
+
+    testExpression("\"b\"<\"a\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"b\"<=\"a\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"b\">=\"a\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"b\">\"a\"",Boolean.TRUE, null, rtp, lib,o);
+
+    testExpression("\"a\"<\"a\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\">\"a\"",Boolean.FALSE, null, rtp, lib,o);
+    testExpression("\"a\"<=\"a\"",Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"a\">=\"a\"",Boolean.TRUE, null, rtp, lib,o);
+
+    testExpression("\"3.0\"==\"\"+aarrDouble[1][0]",Boolean.TRUE,
+                   null, rtp, lib,o);
+
+    testExpression("\"\"==anObject",Boolean.FALSE,null, rtp, lib,o);
+    testExpression("anObject==anObject",Boolean.TRUE,null, rtp, lib,o);
+    testExpression("anObject!=anObject",Boolean.FALSE,null, rtp, lib,o);
+    testExpression("!(anObject==anObject)",Boolean.FALSE,null, rtp, lib,o);
+
+
+    o.println(); o.println("----- Automatic widening conversions of "+
+                           "references ------");
+
+    testExpression("convertNumberToInt(makeDoubleObject(5.0))",new Integer(5),
+                   null, rtp, lib,o);
+    testExpression("convertNumberToInt(arrIntegerObj[0])",new Integer(1),
+                   null, rtp, lib,o);
+    testExpression("convertNumberToDouble(arrIntegerObj[0])",
+                   new Double(1.0),
+                   null, rtp, lib,o);
+    testExpression("convertNumberToDouble(makeDoubleObject(5.0))",
+                   new Double(5.0),
+                   null, rtp, lib,o);
+    testExpression("convertNumberToDouble(makeDoubleObject(5.0))",
+                   new Double(5.0),
+                   null, rtp, lib,o);
+    testExpression("addNumbersDbl(makeDoubleObject(5.0),arrIntegerObj[0])",
+                   new Double(6.0),
+                   null, rtp, lib,o);
+    testExpression("addNumbersInt(makeDoubleObject(5.0),arrIntegerObj[0])",
+                   new Integer(6),
+                   null, rtp, lib,o);
+    testExpression("isNullDouble(getDoubleNull())",
+                   Boolean.TRUE,
+                   null, rtp, lib,o);
+    testExpression("isNullDouble(makeDoubleObject(5.0))",
+                   Boolean.FALSE,
+                   null, rtp, lib,o);
+
+    o.println(); o.println("----- DOWNCASTING ------");
+    java.util.Hashtable allowedCasts=new java.util.Hashtable();
+    allowedCasts.put("String",String.class);
+    allowedCasts.put("Object",Object.class);
+    allowedCasts.put("Double",java.lang.Double.class);
+    lib=new Library(staticLib,dynamicLib,dotLib,vp,allowedCasts);
+
+    testExpression("(Double)((Object)valDoubleObj)",new Double(1.0),
+                   null, rtp, lib,o);
+    testExpression("((String)((Object)\"abc\")).length",new Integer(3),
+                   null, rtp, lib,o);
+
+    // as per Kumar Pandya's request
+    allowedCasts.put("a1.a2.Strin",String.class);
+    allowedCasts.put("a2.a3.Objec",Object.class);
+    allowedCasts.put("a3.a4.Doubl",java.lang.Double.class);
+
+    testExpression("(a3.a4.Doubl)((a2.a3.Objec)valDoubleObj)",new Double(1.0),
+                   null, rtp, lib,o);
+    testExpression("((a1.a2.Strin)((a2.a3.Objec)\"abc\")).length",new Integer(3),
+                   null, rtp, lib,o);
 
 //      o.println(); o.println("----- MULTI-ROOT DYNAMIC VARIABLES ------");
 //      vp.addProperty("<gnu.jel.tests.IntegerObject>p1","irrelevant value");
